"use client";
import React, { useState, useEffect } from "react";
import { Text, Button, TextInput, PasswordInput, Title, Card, Group, Flex, Box, Image, Anchor, Stack, Popover, ActionIcon } from "@mantine/core";
import { notifications } from "@mantine/notifications";
import { Providers } from "@/app/providers";
import { useRouter } from "next/navigation";
import NextImage from "next/image";
import logo from '@/app/image/logo.jpg';
import frontPage from '@/app/image/ib_front_page.jpg';
import dynamic from 'next/dynamic';
import { generateCaptcha } from '@/app/captcha';

export default function Login() {
    const router = useRouter();
    const [error, setError] = useState<string | null>(null);
    const [CIF, SetCIF] = useState("");
    const [psw, SetPsw] = useState("");
    const [captcha, setCaptcha] = useState("");
    const [inputCaptcha, setInputCaptcha] = useState("");
    const [isLogging, setIsLogging] = useState(false);
    const ClientCarousel = dynamic(() => import('./clientCarousel'), { ssr: false });

    useEffect(() => {
        const loadCaptcha = async () => {
            const newCaptcha = await generateCaptcha();
            setCaptcha(newCaptcha);
        };
        loadCaptcha();
    }, []);

    const regenerateCaptcha = () => {
        // setCaptcha(generateCaptcha());
        const loadCaptcha = async () => {
            const newCaptcha = await generateCaptcha();
            setCaptcha(newCaptcha);
        };
        loadCaptcha();
        setInputCaptcha("");
    };

    async function handleLogin(e: React.FormEvent) {
        e.preventDefault();
        const onlyDigit = /^\d{11}$/;
        if (!onlyDigit.test(CIF)) {
            setError('Input value must be 11 digit');
        }
        if (inputCaptcha !== captcha) {
            notifications.show({
                withBorder: true,
                color: "red",
                title: "Captcha Error",
                message: "Please enter the correct captcha",
                autoClose: 5000,
            });
            return;
        }
        const response = await fetch('api/auth/login', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                customerNo: CIF,
                password: psw,
            }),
        });
        const data = await response.json();
        setIsLogging(true);
        if (response.ok) {
            console.log(data);
            const token = data.token;
            localStorage.setItem("access_token", token);
            if (data.FirstTimeLogin === true) {
                router.push("/ChangePassword")
            }
            else {
                router.push("/home");
            }

        }
        else {
            setIsLogging(false);
            notifications.show({
                withBorder: true,
                color: "red",
                title: "Wrong User Id or Password",
                message: "Wrong User Id or Password",
                autoClose: 5000,
            });
        }
    }

    return (
        <Providers>
            <div style={{ backgroundColor: "#f8f9fa", width: "100%", height: "auto", paddingTop: "5%" }}>
                {/* Header */}
                <Box style={{
                    position: 'fixed', width: '100%', height: '12%', top: 0, left: 0, zIndex: 100,
                    display: "flex",
                    justifyContent: "flex-start",
                    background: "linear-gradient(15deg,rgba(2, 163, 85, 1) 55%, rgba(101, 101, 184, 1) 100%)",
                    // border: "1px solid black"
                }}>
                    <Image
                        fit="cover"
                        src={logo}
                        component={NextImage}
                        alt="ebanking"
                        style={{ width: "40%", height: "100%", objectFit: "contain", marginLeft: 0 }}
                    />
                    <Text
                        style={{
                            position: 'absolute',
                            top: '50%',
                            left: '64%',
                            color: 'white',
                            textShadow: '1px 1px 2px blue',
                        }}
                    >
                        {/* <IconBuildingBank/> */}
                        Head Office : Dharmshala, District: Kangra(H.P), Pincode: 176215
                    </Text>
                </Box>
                <div style={{ marginTop: '10px' }}>
                    {/* Movable text */}
                    <Box
                        style={{
                            width: "100%",
                            height: "0.5%",
                            overflow: "hidden",
                            whiteSpace: "nowrap",
                            padding: "8px 0",
                        }}
                    >
                        <Text
                            component="span"
                            style={{
                                display: "inline-block",
                                paddingLeft: "100%",
                                animation: "scroll-left 60s linear infinite",
                                fontWeight: "bold",
                                color: "#004d99",
                            }}
                        >
                            ⚠️ Always login to our Net Banking site directly or through Banks website.
                            ⚠️ Do not disclose your User Id and Password to any third party and keep Your User Id and Password strictly confidential.
                            ⚠️ KCC Bank never asks for User Id,Passwords and Pins through email or  phone.
                            ⚠️ Be ware of Phishing mails with links to fake bank&apos;s websites asking for personal information are in circulation.
                            ⚠️ Please DO NOT Click on the links given in the emails asking for personal details like bank account number, user ID and password.
                            ⚠️ If you had shard your User Id and Password through such mails or links, please change your Password immediately.
                            ⚠️ Inform the Bank/branch in which your account is maintained for resetting your password.
                        </Text>
                        <style>
                            {`
              @keyframes scroll-left {
                0% { transform: translateX(0%); }
                100% { transform: translateX(-100%); }
              }
            `}
                        </style>
                    </Box>
                    {/* Main */}
                    <div style={{ display: "flex", height: "75vh", overflow: "hidden", position: "relative",
                        background:'linear-gradient(to right, #02081eff, #0a3d91)' }}>
                        <div style={{ flex: 1, backgroundColor: "#c1e0f0", position: "relative" }}>
                            <Image
                                fit="cover"
                                src={frontPage}
                                component={NextImage}
                                alt="ebanking"
                                style={{ width: "100%", height: "100%" }}
                            />
                        </div>
                        <Box w={{ base: "100%", md: "50%" }} p="lg">
                            <Card shadow="md" padding="xl" radius="md" style={{ maxWidth: 400,margin: "0 auto",height:'68vh'}}>
                                <form onSubmit={handleLogin}>
                                    <TextInput
                                        label="User ID"
                                        placeholder="Enter your CIF No"
                                        value={CIF}
                                        onInput={(e) => {
                                            const input = e.currentTarget.value.replace(/\D/g, "");
                                            if (input.length <= 11) SetCIF(input);
                                        }}
                                        error={error}
                                        required
                                    />
                                    <PasswordInput
                                        label="Password"
                                        placeholder="Enter your password"
                                        value={psw}
                                        onChange={(e) => SetPsw(e.currentTarget.value)}
                                        required
                                        mt="sm"
                                    />
                                    <Group mt="sm" align="center">
                                        <Box style={{ backgroundColor: "#fff", fontSize: "18px", textDecoration: "line-through", padding: "4px 8px", fontFamily: "cursive" }}>{captcha}</Box>
                                        <Button size="xs" variant="light" onClick={regenerateCaptcha}>Refresh</Button>
                                    </Group>
                                    <TextInput
                                        label="Enter CAPTCHA"
                                        placeholder="Enter above text"
                                        value={inputCaptcha}
                                        onChange={(e) => setInputCaptcha(e.currentTarget.value)}
                                        required
                                        mt="sm"
                                    />
                                    <Button type="submit" fullWidth mt="md" disabled={isLogging}>
                                        {isLogging ? "Logging..." : "Login"}
                                    </Button>
                                </form>
                            </Card>
                        </Box>
                    </div>
                    {/* Carousel and Notes */}
                    <Flex direction={{ base: "column", md: "row" }} mt="lg" p="lg">
                        <Box w={{ base: "100%", md: "60%" }}>
                            <ClientCarousel />
                        </Box>
                        <Box w={{ base: "100%", md: "40%" }} p="md" style={{ textAlign: "center" }}>
                            <Title order={2}>Security Notes :</Title>
                            <Text mt="sm" size="md">When you Login, Your User Id and Password travels in an encrypted and highly secured mode.</Text>
                            <Text mt="sm" fs="italic">For more information on Products and Services, Please Visit</Text>
                            <Anchor> http://www.kccb.in/</Anchor>
                        </Box>
                    </Flex>
                    {/* Footer */}
                    <Box
                        component="footer"
                        style={{
                            width: "100%",
                            textAlign: "center",
                            padding: "10px 0",
                            bottom: 0,
                            left: 0,
                            zIndex: 1000,
                            fontSize: "14px",
                        }}
                    >
                        <Text>
                            © 2025 KCC Bank. All rights reserved. |{" "}
                            <Anchor href="document/disclaimer.pdf" target="_blank" rel="noopener noreferrer">Disclaimer</Anchor> |{" "}
                            <Anchor href="document/privacy_policy.pdf" target="_blank" rel="noopener noreferrer">Privacy Policy</Anchor> |{" "}
                            <Anchor href="document/phishing.pdf" target="_blank" rel="noopener noreferrer">Phishing</Anchor> |{" "}
                            <Anchor href="document/security_tips.pdf" target="_blank" rel="noopener noreferrer">Security Tips</Anchor> |{" "}
                            <Anchor href="document/grievance.jpg" target="_blank" rel="noopener noreferrer">Grievances</Anchor>
                        </Text>
                    </Box>
                </div>
            </div>
        </Providers>
    );
}
